UMA-ASE Visualizer

Calculate
Visualize

## Input Details

Select Geometry Input file No file selected.
Charge
Spin Multiplicity
MLFF Checkpoint
MLFF Task
Run Type
Single Point GeoOpt Frequencies
Summary

    No structure loaded.

## Input Details

Geometry Input file No file selected.
Charge
Spin Multiplicity
Summary

    No structure loaded.

## 3D Visualizer

The visualizer automatically loads the geometry selected on Calculate tab. Load a different file below to preview without replacing the main selection.